#[repr(C)]pub struct PlaneData {
pub normal: Vec4,
pub origin: Vec4,
}Expand description
Per-item plane data (normal + origin), stored as array of structs. The origin is the first point of the item (used by vertex shader). basis_u/basis_v are generated deterministically from the normal in the shader.
Fields
normal: Vec4origin: Vec4Trait Implementations
impl Copy for PlaneData
impl Pod for PlaneData